@@ -390,7 +390,7 @@ class Excel():
         table = Table(displayName = table_name, ref = self.get_range(left_top, right_bottom))
 
         # basic style for the table
-        style = TableStyleInfo(name=ExcelTableStyles.Dark_Blue.value, showFirstColumn=False,
+        style = TableStyleInfo(name=ExcelTableStyles.MediumBlue1.value, showFirstColumn=False,
                                showLastColumn=False, showRowStripes=True, showColumnStripes=False)
         table.tableStyleInfo = style
         sheet.add_table(table)
